drama.shaders = {};
drama.shaders["hsladjust"] = {
	src: "varying mediump vec2 vTex;\nuniform lowp sampler2D samplerFront;\nprecision mediump float;\nuniform float huerotate;\nuniform float satadjust;\nuniform float lumadjust;\n\nvec3 rgb_to_hsl(vec3 color)\n{\n	vec3 hsl = vec3(0.0, 0.0, 0.0);\n	\n	float fmin = min(min(color.r, color.g), color.b);\n	float fmax = max(max(color.r, color.g), color.b);\n	float delta = fmax - fmin;\n\n	hsl.z = (fmax + fmin) / 2.0;\n\n	if (delta == 0.0)\n	{\n		hsl.x = 0.0;\n		hsl.y = 0.0;\n	}\n	else \n	{\n		if (hsl.z < 0.5)\n			hsl.y = delta / (fmax + fmin);\n		else\n			hsl.y = delta / (2.0 - fmax - fmin);\n		\n		float dR = (((fmax - color.r) / 6.0) + (delta / 2.0)) / delta;\n		float dG = (((fmax - color.g) / 6.0) + (delta / 2.0)) / delta;\n		float dB = (((fmax - color.b) / 6.0) + (delta / 2.0)) / delta;\n\n		if (color.r == fmax)\n			hsl.x = dB - dG;\n		else if (color.g == fmax)\n			hsl.x = (1.0 / 3.0) + dR - dB;\n		else if (color.b == fmax)\n			hsl.x = (2.0 / 3.0) + dG - dR;\n\n		if (hsl.x < 0.0)\n			hsl.x += 1.0;\n		else if (hsl.x > 1.0)\n			hsl.x -= 1.0;\n	}\n\n	return hsl;\n}\n\nfloat hue_to_rgb(float f1, float f2, float hue)\n{\n	if (hue < 0.0)\n		hue += 1.0;\n	else if (hue > 1.0)\n		hue -= 1.0;\n		\n	float ret;\n	\n	if ((6.0 * hue) < 1.0)\n		ret = f1 + (f2 - f1) * 6.0 * hue;\n	else if ((2.0 * hue) < 1.0)\n		ret = f2;\n	else if ((3.0 * hue) < 2.0)\n		ret = f1 + (f2 - f1) * ((2.0 / 3.0) - hue) * 6.0;\n	else\n		ret = f1;\n	\n	return ret;\n}\n\nvec3 hsl_to_rgb(vec3 hsl)\n{\n	vec3 rgb = vec3(hsl.z);\n	\n	if (hsl.y != 0.0)\n	{\n		float f2;\n		\n		if (hsl.z < 0.5)\n			f2 = hsl.z * (1.0 + hsl.y);\n		else\n			f2 = (hsl.z + hsl.y) - (hsl.y * hsl.z);\n			\n		float f1 = 2.0 * hsl.z - f2;\n		\n		rgb.r = hue_to_rgb(f1, f2, hsl.x + (1.0 / 3.0));\n		rgb.g = hue_to_rgb(f1, f2, hsl.x);\n		rgb.b = hue_to_rgb(f1, f2, hsl.x - (1.0 / 3.0));\n	}\n	\n	return rgb;\n}\n\nvoid main(void)\n{	vec4 front = texture2D(samplerFront, vTex);\n	vec3 rgb = rgb_to_hsl(front.rgb) + vec3(huerotate, 0, (lumadjust - 1.0) * front.a);\n	rgb.y *= satadjust;\n	rgb = hsl_to_rgb(rgb);\n	gl_FragColor = vec4(rgb, front.a);\n}\n",
	extendBoxHorizontal: 0,
	extendBoxVertical: 0,
	crossSampling: false,
	preservesOpaqueness: true,
	animated: false,
	parameters: [["huerotate",0,1],["satadjust",0,1],["lumadjust",0,1]]
};
